@@ -1,7 +1,7 @@
 package Carmel;
 use strict;
 use 5.010_001;
-use version; our $VERSION = version->declare('v0.1.19');
+use version; our $VERSION = version->declare('v0.1.20');
 
 1;
 __END__
@@ -33,11 +33,17 @@ Carmel - CPAN Artifact Repository Manager
   carmel exec perl ...
 
   # Requires all your modules in cpanfile in one shot
-  carmel exec perl -e 'Carmel::Runtime->require_all'
+  carmel exec perl -e 'use Carmel::Preload;'
 
   # Roll out the currently selected modules into ./local
   carmel rollout
 
+  # package modules tarballs and index into ./vendor/cache
+  carmel package
+
+  # use Carmel packages inside a script (without carmel exec)
+  perl -e 'use Carmel::Setup; ...'
+
   # prints export PATH=... etc for shell scripting
   carmel export
 
